==> igniteui-webcomponents-core-3.5.0.tgz: package/esm2015/lib/WebCancelableEventArgsDetailDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { WebCancelableEventArgsDetailDescription } from "./WebCancelableEventArgsDetailDescription";
/**
 * @hidden
 */
export let WebCancelableEventArgsDetailDescriptionMetadata = /*@__PURE__*/ (() => {
    class WebCancelableEventArgsDetailDescriptionMetadata extends Base {
        static b(a) {
            if (WebCancelableEventArgsDetailDescriptionMetadata.a == null) {
                WebCancelableEventArgsDetailDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
                WebCancelableEventArgsDetailDescriptionMetadata.c(WebCancelableEventArgsDetailDescriptionMetadata.a);
            }
            if (a.j(WebCancelableEventArgsDetailDescriptionMetadata.a)) {
                return;
            }
            a.y(WebCancelableEventArgsDetailDescriptionMetadata.a);
        }
        static c(a) {
            a.item("__qualifiedNameTS", "String:CancelableEventArgsDetail");
            a.item("__packageNameWC", "String:grids");
            a.item("__isPlainObject", "Boolean");
            a.item("Cancel", "Boolean");
        }
        static d(a) {
            WebCancelableEventArgsDetailDescriptionMetadata.b(a);
            a.aa("WebCancelableEventArgsDetail", () => new WebCancelableEventArgsDetailDescription());
            a.z("WebCancelableEventArgsDetail", WebCancelableEventArgsDetailDescriptionMetadata.a);
        }
    }
    WebCancelableEventArgsDetailDescriptionMetadata.$t = /*@__PURE__*/ markType(WebCancelableEventArgsDetailDescriptionMetadata, 'WebCancelableEventArgsDetailDescriptionMetadata');
    WebCancelableEventArgsDetailDescriptionMetadata.a = null;
    return WebCancelableEventArgsDetailDescriptionMetadata;
})();

==> igniteui-webcomponents-core-4.2.5.tgz: package/esm2015/lib/WebCancelableEventArgsDetailDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { WebCancelableEventArgsDetailDescription } from "./WebCancelableEventArgsDetailDescription";
/**
 * @hidden
 */
export let WebCancelableEventArgsDetailDescriptionMetadata = /*@__PURE__*/ (() => {
    class WebCancelableEventArgsDetailDescriptionMetadata extends Base {
        static b(a) {
            if (WebCancelableEventArgsDetailDescriptionMetadata.a == null) {
                WebCancelableEventArgsDetailDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
                WebCancelableEventArgsDetailDescriptionMetadata.c(WebCancelableEventArgsDetailDescriptionMetadata.a);
            }
            if (a.k(WebCancelableEventArgsDetailDescriptionMetadata.a)) {
                return;
            }
            a.aa(WebCancelableEventArgsDetailDescriptionMetadata.a);
        }
        static c(a) {
            a.item("__qualifiedNameTS", "String:CancelableEventArgsDetail");
            a.item("__packageNameWC", "String:grids");
            a.item("__skipModuleRegisterWebComponents", "Boolean");
            a.item("__importOverrideWebComponents", "String:igniteui-webcomponents-grids/grids/combined");
            a.item("__importTypesWebComponents", "String:igniteui-webcomponents-grids/grids");
            a.item("__isPlainObject", "Boolean");
            a.item("__skipSuffix", "Boolean");
            a.item("Cancel", "Boolean");
        }
        static d(a) {
            WebCancelableEventArgsDetailDescriptionMetadata.b(a);
            a.ac("WebCancelableEventArgsDetail", () => new WebCancelableEventArgsDetailDescription());
            a.ab("WebCancelableEventArgsDetail", WebCancelableEventArgsDetailDescriptionMetadata.a);
        }
    }
    WebCancelableEventArgsDetailDescriptionMetadata.$t = /*@__PURE__*/ markType(WebCancelableEventArgsDetailDescriptionMetadata, 'WebCancelableEventArgsDetailDescriptionMetadata');
    WebCancelableEventArgsDetailDescriptionMetadata.a = null;
    return WebCancelableEventArgsDetailDescriptionMetadata;
})();
